@@ -9,6 +9,7 @@ from atomate.vasp.config import SMALLGAP_KPOINT_MULTIPLY, STABILITY_CHECK, VASP_
     ADD_WF_METADATA, VDW_KERNEL_DIR
 import numpy as np
 import os
+from fireworks import  Workflow
 from monty.serialization import loadfn
 from pathlib import Path
 
@@ -149,6 +150,8 @@ def wf_bandstructure2D(structure, c=None):
         wf = add_wf_metadata(wf, structure)
     new_firework = OptimizeFW2D(structure=structure, vasp_input_set= mpr2d, vasp_cmd=vasp_cmd, db_file=db_file, vdw_kernel_dir=vdw_kernel)
     print(wf)
-    wf[0] = new_firework
-    print(wf)
+    fws = wf.fws
+    fws[0] = new_firework
+    print(fws)
+    wf = Workflow(fws)
     return wf
\ No newline at end of file
